from . import simpl

def generate_vertex_coordinates(data_container_array, selected_data_container_name = None, coordinate_array_path = None, observer = None) -> int:
  """Pythonic interface to GenerateVertexCoordinates Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    selected_data_container_name (DataArrayPath): Sets the "SelectedDataContainerName" filter property
    coordinate_array_path (DataArrayPath): Sets the "CoordinateArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = simpl.GenerateVertexCoordinates()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if selected_data_container_name is not None:
    filter.SelectedDataContainerName = selected_data_container_name
  if coordinate_array_path is not None:
    filter.CoordinateArrayPath = coordinate_array_path
  filter.execute()
  return filter.ErrorCode

def array_calculator(data_container_array, selected_attribute_matrix = None, infix_equation = None, calculated_array = None, units = None, scalar_type = None, observer = None) -> int:
  """Pythonic interface to ArrayCalculator Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    selected_attribute_matrix (DataArrayPath): Sets the "SelectedAttributeMatrix" filter property
    infix_equation (QString): Sets the "InfixEquation" filter property
    calculated_array (DataArrayPath): Sets the "CalculatedArray" filter property
    units (ArrayCalculator::AngleUnits): Sets the "Units" filter property
    scalar_type (SIMPL::ScalarTypes::Type): Sets the "ScalarType" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = simpl.ArrayCalculator()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if selected_attribute_matrix is not None:
    filter.SelectedAttributeMatrix = selected_attribute_matrix
  if infix_equation is not None:
    filter.InfixEquation = infix_equation
  if calculated_array is not None:
    filter.CalculatedArray = calculated_array
  if units is not None:
    filter.Units = units
  if scalar_type is not None:
    filter.ScalarType = scalar_type
  filter.execute()
  return filter.ErrorCode

def combine_attribute_arrays(data_container_array, selected_data_array_paths = None, stacked_data_array_name = None, normalize_data = None, observer = None) -> int:
  """Pythonic interface to CombineAttributeArrays Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    selected_data_array_paths (std::vector<DataArrayPath>): Sets the "SelectedDataArrayPaths" filter property
    stacked_data_array_name (QString): Sets the "StackedDataArrayName" filter property
    normalize_data (bool): Sets the "NormalizeData" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = simpl.CombineAttributeArrays()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if selected_data_array_paths is not None:
    filter.SelectedDataArrayPaths = selected_data_array_paths
  if stacked_data_array_name is not None:
    filter.StackedDataArrayName = stacked_data_array_name
  if normalize_data is not None:
    filter.NormalizeData = normalize_data
  filter.execute()
  return filter.ErrorCode

def combine_attribute_matrices(data_container_array, first_attribute_matrix_path = None, second_attribute_matrix_path = None, first_index_array_path = None, second_index_array_path = None, combined_attribute_matrix_name = None, new_index_array_name = None, observer = None) -> int:
  """Pythonic interface to CombineAttributeMatrices Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    first_attribute_matrix_path (DataArrayPath): Sets the "FirstAttributeMatrixPath" filter property
    second_attribute_matrix_path (DataArrayPath): Sets the "SecondAttributeMatrixPath" filter property
    first_index_array_path (DataArrayPath): Sets the "FirstIndexArrayPath" filter property
    second_index_array_path (DataArrayPath): Sets the "SecondIndexArrayPath" filter property
    combined_attribute_matrix_name (QString): Sets the "CombinedAttributeMatrixName" filter property
    new_index_array_name (QString): Sets the "NewIndexArrayName" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = simpl.CombineAttributeMatrices()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if first_attribute_matrix_path is not None:
    filter.FirstAttributeMatrixPath = first_attribute_matrix_path
  if second_attribute_matrix_path is not None:
    filter.SecondAttributeMatrixPath = second_attribute_matrix_path
  if first_index_array_path is not None:
    filter.FirstIndexArrayPath = first_index_array_path
  if second_index_array_path is not None:
    filter.SecondIndexArrayPath = second_index_array_path
  if combined_attribute_matrix_name is not None:
    filter.CombinedAttributeMatrixName = combined_attribute_matrix_name
  if new_index_array_name is not None:
    filter.NewIndexArrayName = new_index_array_name
  filter.execute()
  return filter.ErrorCode

def conditional_set_value(data_container_array, selected_array_path = None, conditional_array_path = None, replace_value = None, observer = None) -> int:
  """Pythonic interface to ConditionalSetValue Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    selected_array_path (DataArrayPath): Sets the "SelectedArrayPath" filter property
    conditional_array_path (DataArrayPath): Sets the "ConditionalArrayPath" filter property
    replace_value (double): Sets the "ReplaceValue" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = simpl.ConditionalSetValue()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if selected_array_path is not None:
    filter.SelectedArrayPath = selected_array_path
  if conditional_array_path is not None:
    filter.ConditionalArrayPath = conditional_array_path
  if replace_value is not None:
    filter.ReplaceValue = replace_value
  filter.execute()
  return filter.ErrorCode

def convert_color_to_gray_scale(data_container_array, conversion_algorithm = None, color_weights = None, color_channel = None, input_data_array_vector = None, create_new_attribute_matrix = None, output_attribute_matrix_name = None, output_array_prefix = None, observer = None) -> int:
  """Pythonic interface to ConvertColorToGrayScale Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    conversion_algorithm (int): Sets the "ConversionAlgorithm" filter property
    color_weights (FloatVec3Type): Sets the "ColorWeights" filter property
    color_channel (int): Sets the "ColorChannel" filter property
    input_data_array_vector (std::vector<DataArrayPath>): Sets the "InputDataArrayVector" filter property
    create_new_attribute_matrix (bool): Sets the "CreateNewAttributeMatrix" filter property
    output_attribute_matrix_name (QString): Sets the "OutputAttributeMatrixName" filter property
    output_array_prefix (QString): Sets the "OutputArrayPrefix" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = simpl.ConvertColorToGrayScale()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if conversion_algorithm is not None:
    filter.ConversionAlgorithm = conversion_algorithm
  if color_weights is not None:
    filter.ColorWeights = color_weights
  if color_channel is not None:
    filter.ColorChannel = color_channel
  if input_data_array_vector is not None:
    filter.InputDataArrayVector = input_data_array_vector
  if create_new_attribute_matrix is not None:
    filter.CreateNewAttributeMatrix = create_new_attribute_matrix
  if output_attribute_matrix_name is not None:
    filter.OutputAttributeMatrixName = output_attribute_matrix_name
  if output_array_prefix is not None:
    filter.OutputArrayPrefix = output_array_prefix
  filter.execute()
  return filter.ErrorCode

def convert_data(data_container_array, scalar_type = None, output_array_name = None, selected_cell_array_path = None, observer = None) -> int:
  """Pythonic interface to ConvertData Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    scalar_type (SIMPL::NumericTypes::Type): Sets the "ScalarType" filter property
    output_array_name (QString): Sets the "OutputArrayName" filter property
    selected_cell_array_path (DataArrayPath): Sets the "SelectedCellArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = simpl.ConvertData()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if scalar_type is not None:
    filter.ScalarType = scalar_type
  if output_array_name is not None:
    filter.OutputArrayName = output_array_name
  if selected_cell_array_path is not None:
    filter.SelectedCellArrayPath = selected_cell_array_path
  filter.execute()
  return filter.ErrorCode

def extract_vertex_geometry(data_container_array, array_handling = None, selected_data_container_name = None, included_data_array_paths = None, mask_array_path = None, use_mask = None, vertex_data_container_name = None, observer = None) -> int:
  """Pythonic interface to ExtractVertexGeometry Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    array_handling (int): Sets the "ArrayHandling" filter property
    selected_data_container_name (DataArrayPath): Sets the "SelectedDataContainerName" filter property
    included_data_array_paths (std::vector<DataArrayPath>): Sets the "IncludedDataArrayPaths" filter property
    mask_array_path (DataArrayPath): Sets the "MaskArrayPath" filter property
    use_mask (bool): Sets the "UseMask" filter property
    vertex_data_container_name (DataArrayPath): Sets the "VertexDataContainerName" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = simpl.ExtractVertexGeometry()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if array_handling is not None:
    filter.ArrayHandling = array_handling
  if selected_data_container_name is not None:
    filter.SelectedDataContainerName = selected_data_container_name
  if included_data_array_paths is not None:
    filter.IncludedDataArrayPaths = included_data_array_paths
  if mask_array_path is not None:
    filter.MaskArrayPath = mask_array_path
  if use_mask is not None:
    filter.UseMask = use_mask
  if vertex_data_container_name is not None:
    filter.VertexDataContainerName = vertex_data_container_name
  filter.execute()
  return filter.ErrorCode

def copy_feature_array_to_element_array(data_container_array, selected_feature_array_path = None, feature_ids_array_path = None, created_array_name = None, observer = None) -> int:
  """Pythonic interface to CopyFeatureArrayToElementArray Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    selected_feature_array_path (DataArrayPath): Sets the "SelectedFeatureArrayPath" filter property
    feature_ids_array_path (DataArrayPath): Sets the "FeatureIdsArrayPath" filter property
    created_array_name (QString): Sets the "CreatedArrayName" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = simpl.CopyFeatureArrayToElementArray()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if selected_feature_array_path is not None:
    filter.SelectedFeatureArrayPath = selected_feature_array_path
  if feature_ids_array_path is not None:
    filter.FeatureIdsArrayPath = feature_ids_array_path
  if created_array_name is not None:
    filter.CreatedArrayName = created_array_name
  filter.execute()
  return filter.ErrorCode

def create_attribute_matrix(data_container_array, created_attribute_matrix = None, attribute_matrix_type = None, tuple_dimensions = None, observer = None) -> int:
  """Pythonic interface to CreateAttributeMatrix Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    created_attribute_matrix (DataArrayPath): Sets the "CreatedAttributeMatrix" filter property
    attribute_matrix_type (int): Sets the "AttributeMatrixType" filter property
    tuple_dimensions (DynamicTableData): Sets the "TupleDimensions" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = simpl.CreateAttributeMatrix()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if created_attribute_matrix is not None:
    filter.CreatedAttributeMatrix = created_attribute_matrix
  if attribute_matrix_type is not None:
    filter.AttributeMatrixType = attribute_matrix_type
  if tuple_dimensions is not None:
    filter.TupleDimensions = tuple_dimensions
  filter.execute()
  return filter.ErrorCode

def create_data_array(data_container_array, scalar_type = None, number_of_components = None, new_array = None, initialization_type = None, initialization_value = None, initialization_range = None, starting_index_value = None, observer = None) -> int:
  """Pythonic interface to CreateDataArray Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    scalar_type (SIMPL::ScalarTypes::Type): Sets the "ScalarType" filter property
    number_of_components (int): Sets the "NumberOfComponents" filter property
    new_array (DataArrayPath): Sets the "NewArray" filter property
    initialization_type (int): Sets the "InitializationType" filter property
    initialization_value (QString): Sets the "InitializationValue" filter property
    initialization_range (FPRangePair): Sets the "InitializationRange" filter property
    starting_index_value (int): Sets the "StartingIndexValue" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = simpl.CreateDataArray()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if scalar_type is not None:
    filter.ScalarType = scalar_type
  if number_of_components is not None:
    filter.NumberOfComponents = number_of_components
  if new_array is not None:
    filter.NewArray = new_array
  if initialization_type is not None:
    filter.InitializationType = initialization_type
  if initialization_value is not None:
    filter.InitializationValue = initialization_value
  if initialization_range is not None:
    filter.InitializationRange = initialization_range
  if starting_index_value is not None:
    filter.StartingIndexValue = starting_index_value
  filter.execute()
  return filter.ErrorCode

def create_data_container(data_container_array, data_container_name = None, observer = None) -> int:
  """Pythonic interface to CreateDataContainer Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    data_container_name (DataArrayPath): Sets the "DataContainerName" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = simpl.CreateDataContainer()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if data_container_name is not None:
    filter.DataContainerName = data_container_name
  filter.execute()
  return filter.ErrorCode

def create_feature_array_from_element_array(data_container_array, cell_feature_attribute_matrix_name = None, selected_cell_array_path = None, created_array_name = None, feature_ids_array_path = None, observer = None) -> int:
  """Pythonic interface to CreateFeatureArrayFromElementArray Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    cell_feature_attribute_matrix_name (DataArrayPath): Sets the "CellFeatureAttributeMatrixName" filter property
    selected_cell_array_path (DataArrayPath): Sets the "SelectedCellArrayPath" filter property
    created_array_name (QString): Sets the "CreatedArrayName" filter property
    feature_ids_array_path (DataArrayPath): Sets the "FeatureIdsArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = simpl.CreateFeatureArrayFromElementArray()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if cell_feature_attribute_matrix_name is not None:
    filter.CellFeatureAttributeMatrixName = cell_feature_attribute_matrix_name
  if selected_cell_array_path is not None:
    filter.SelectedCellArrayPath = selected_cell_array_path
  if created_array_name is not None:
    filter.CreatedArrayName = created_array_name
  if feature_ids_array_path is not None:
    filter.FeatureIdsArrayPath = feature_ids_array_path
  filter.execute()
  return filter.ErrorCode

def create_image_geometry(data_container_array, selected_data_container = None, dimensions = None, origin = None, spacing = None, observer = None) -> int:
  """Pythonic interface to CreateImageGeometry Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    selected_data_container (DataArrayPath): Sets the "SelectedDataContainer" filter property
    dimensions (IntVec3Type): Sets the "Dimensions" filter property
    origin (FloatVec3Type): Sets the "Origin" filter property
    spacing (FloatVec3Type): Sets the "Spacing" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = simpl.CreateImageGeometry()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if selected_data_container is not None:
    filter.SelectedDataContainer = selected_data_container
  if dimensions is not None:
    filter.Dimensions = dimensions
  if origin is not None:
    filter.Origin = origin
  if spacing is not None:
    filter.Spacing = spacing
  filter.execute()
  return filter.ErrorCode

def create_grid_montage(data_container_array, montage_name = None, grid_selection = None, data_container_name_list = None, observer = None) -> int:
  """Pythonic interface to CreateGridMontage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    montage_name (QString): Sets the "MontageName" filter property
    grid_selection (DataContainerGrid): Sets the "GridSelection" filter property
    data_container_name_list (QStringList): Sets the "DataContainerNameList" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = simpl.CreateGridMontage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if montage_name is not None:
    filter.MontageName = montage_name
  if grid_selection is not None:
    filter.GridSelection = grid_selection
  if data_container_name_list is not None:
    filter.DataContainerNameList = data_container_name_list
  filter.execute()
  return filter.ErrorCode

def create_string_array(data_container_array, number_of_components = None, new_array = None, initialization_value = None, observer = None) -> int:
  """Pythonic interface to CreateStringArray Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    number_of_components (int): Sets the "NumberOfComponents" filter property
    new_array (DataArrayPath): Sets the "NewArray" filter property
    initialization_value (QString): Sets the "InitializationValue" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = simpl.CreateStringArray()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if number_of_components is not None:
    filter.NumberOfComponents = number_of_components
  if new_array is not None:
    filter.NewArray = new_array
  if initialization_value is not None:
    filter.InitializationValue = initialization_value
  filter.execute()
  return filter.ErrorCode

def copy_object(data_container_array, object_to_copy = None, data_container_to_copy = None, attribute_matrix_to_copy = None, attribute_array_to_copy = None, copied_object_name = None, observer = None) -> int:
  """Pythonic interface to CopyObject Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    object_to_copy (int): Sets the "ObjectToCopy" filter property
    data_container_to_copy (DataArrayPath): Sets the "DataContainerToCopy" filter property
    attribute_matrix_to_copy (DataArrayPath): Sets the "AttributeMatrixToCopy" filter property
    attribute_array_to_copy (DataArrayPath): Sets the "AttributeArrayToCopy" filter property
    copied_object_name (QString): Sets the "CopiedObjectName" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = simpl.CopyObject()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if object_to_copy is not None:
    filter.ObjectToCopy = object_to_copy
  if data_container_to_copy is not None:
    filter.DataContainerToCopy = data_container_to_copy
  if attribute_matrix_to_copy is not None:
    filter.AttributeMatrixToCopy = attribute_matrix_to_copy
  if attribute_array_to_copy is not None:
    filter.AttributeArrayToCopy = attribute_array_to_copy
  if copied_object_name is not None:
    filter.CopiedObjectName = copied_object_name
  filter.execute()
  return filter.ErrorCode

def create_geometry(data_container_array, geometry_type = None, data_container_name = None, shared_vertex_list_array_path0 = None, shared_vertex_list_array_path1 = None, shared_vertex_list_array_path2 = None, shared_vertex_list_array_path3 = None, shared_vertex_list_array_path4 = None, shared_edge_list_array_path = None, shared_tri_list_array_path = None, shared_quad_list_array_path = None, shared_tet_list_array_path = None, x_bounds_array_path = None, y_bounds_array_path = None, z_bounds_array_path = None, dimensions = None, origin = None, spacing = None, image_cell_attribute_matrix_name = None, rect_grid_cell_attribute_matrix_name = None, vertex_attribute_matrix_name0 = None, vertex_attribute_matrix_name1 = None, vertex_attribute_matrix_name2 = None, vertex_attribute_matrix_name3 = None, vertex_attribute_matrix_name4 = None, edge_attribute_matrix_name = None, face_attribute_matrix_name0 = None, face_attribute_matrix_name1 = None, tet_cell_attribute_matrix_name = None, treat_warnings_as_errors = None, array_handling = None, observer = None) -> int:
  """Pythonic interface to CreateGeometry Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    geometry_type (int): Sets the "GeometryType" filter property
    data_container_name (DataArrayPath): Sets the "DataContainerName" filter property
    shared_vertex_list_array_path0 (DataArrayPath): Sets the "SharedVertexListArrayPath0" filter property
    shared_vertex_list_array_path1 (DataArrayPath): Sets the "SharedVertexListArrayPath1" filter property
    shared_vertex_list_array_path2 (DataArrayPath): Sets the "SharedVertexListArrayPath2" filter property
    shared_vertex_list_array_path3 (DataArrayPath): Sets the "SharedVertexListArrayPath3" filter property
    shared_vertex_list_array_path4 (DataArrayPath): Sets the "SharedVertexListArrayPath4" filter property
    shared_edge_list_array_path (DataArrayPath): Sets the "SharedEdgeListArrayPath" filter property
    shared_tri_list_array_path (DataArrayPath): Sets the "SharedTriListArrayPath" filter property
    shared_quad_list_array_path (DataArrayPath): Sets the "SharedQuadListArrayPath" filter property
    shared_tet_list_array_path (DataArrayPath): Sets the "SharedTetListArrayPath" filter property
    x_bounds_array_path (DataArrayPath): Sets the "XBoundsArrayPath" filter property
    y_bounds_array_path (DataArrayPath): Sets the "YBoundsArrayPath" filter property
    z_bounds_array_path (DataArrayPath): Sets the "ZBoundsArrayPath" filter property
    dimensions (IntVec3Type): Sets the "Dimensions" filter property
    origin (FloatVec3Type): Sets the "Origin" filter property
    spacing (FloatVec3Type): Sets the "Spacing" filter property
    image_cell_attribute_matrix_name (QString): Sets the "ImageCellAttributeMatrixName" filter property
    rect_grid_cell_attribute_matrix_name (QString): Sets the "RectGridCellAttributeMatrixName" filter property
    vertex_attribute_matrix_name0 (QString): Sets the "VertexAttributeMatrixName0" filter property
    vertex_attribute_matrix_name1 (QString): Sets the "VertexAttributeMatrixName1" filter property
    vertex_attribute_matrix_name2 (QString): Sets the "VertexAttributeMatrixName2" filter property
    vertex_attribute_matrix_name3 (QString): Sets the "VertexAttributeMatrixName3" filter property
    vertex_attribute_matrix_name4 (QString): Sets the "VertexAttributeMatrixName4" filter property
    edge_attribute_matrix_name (QString): Sets the "EdgeAttributeMatrixName" filter property
    face_attribute_matrix_name0 (QString): Sets the "FaceAttributeMatrixName0" filter property
    face_attribute_matrix_name1 (QString): Sets the "FaceAttributeMatrixName1" filter property
    tet_cell_attribute_matrix_name (QString): Sets the "TetCellAttributeMatrixName" filter property
    treat_warnings_as_errors (bool): Sets the "TreatWarningsAsErrors" filter property
    array_handling (bool): Sets the "ArrayHandling" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = simpl.CreateGeometry()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if geometry_type is not None:
    filter.GeometryType = geometry_type
  if data_container_name is not None:
    filter.DataContainerName = data_container_name
  if shared_vertex_list_array_path0 is not None:
    filter.SharedVertexListArrayPath0 = shared_vertex_list_array_path0
  if shared_vertex_list_array_path1 is not None:
    filter.SharedVertexListArrayPath1 = shared_vertex_list_array_path1
  if shared_vertex_list_array_path2 is not None:
    filter.SharedVertexListArrayPath2 = shared_vertex_list_array_path2
  if shared_vertex_list_array_path3 is not None:
    filter.SharedVertexListArrayPath3 = shared_vertex_list_array_path3
  if shared_vertex_list_array_path4 is not None:
    filter.SharedVertexListArrayPath4 = shared_vertex_list_array_path4
  if shared_edge_list_array_path is not None:
    filter.SharedEdgeListArrayPath = shared_edge_list_array_path
  if shared_tri_list_array_path is not None:
    filter.SharedTriListArrayPath = shared_tri_list_array_path
  if shared_quad_list_array_path is not None:
    filter.SharedQuadListArrayPath = shared_quad_list_array_path
  if shared_tet_list_array_path is not None:
    filter.SharedTetListArrayPath = shared_tet_list_array_path
  if x_bounds_array_path is not None:
    filter.XBoundsArrayPath = x_bounds_array_path
  if y_bounds_array_path is not None:
    filter.YBoundsArrayPath = y_bounds_array_path
  if z_bounds_array_path is not None:
    filter.ZBoundsArrayPath = z_bounds_array_path
  if dimensions is not None:
    filter.Dimensions = dimensions
  if origin is not None:
    filter.Origin = origin
  if spacing is not None:
    filter.Spacing = spacing
  if image_cell_attribute_matrix_name is not None:
    filter.ImageCellAttributeMatrixName = image_cell_attribute_matrix_name
  if rect_grid_cell_attribute_matrix_name is not None:
    filter.RectGridCellAttributeMatrixName = rect_grid_cell_attribute_matrix_name
  if vertex_attribute_matrix_name0 is not None:
    filter.VertexAttributeMatrixName0 = vertex_attribute_matrix_name0
  if vertex_attribute_matrix_name1 is not None:
    filter.VertexAttributeMatrixName1 = vertex_attribute_matrix_name1
  if vertex_attribute_matrix_name2 is not None:
    filter.VertexAttributeMatrixName2 = vertex_attribute_matrix_name2
  if vertex_attribute_matrix_name3 is not None:
    filter.VertexAttributeMatrixName3 = vertex_attribute_matrix_name3
  if vertex_attribute_matrix_name4 is not None:
    filter.VertexAttributeMatrixName4 = vertex_attribute_matrix_name4
  if edge_attribute_matrix_name is not None:
    filter.EdgeAttributeMatrixName = edge_attribute_matrix_name
  if face_attribute_matrix_name0 is not None:
    filter.FaceAttributeMatrixName0 = face_attribute_matrix_name0
  if face_attribute_matrix_name1 is not None:
    filter.FaceAttributeMatrixName1 = face_attribute_matrix_name1
  if tet_cell_attribute_matrix_name is not None:
    filter.TetCellAttributeMatrixName = tet_cell_attribute_matrix_name
  if treat_warnings_as_errors is not None:
    filter.TreatWarningsAsErrors = treat_warnings_as_errors
  if array_handling is not None:
    filter.ArrayHandling = array_handling
  filter.execute()
  return filter.ErrorCode

def crop_vertex_geometry(data_container_array, data_container_name = None, cropped_data_container_name = None, x_min = None, y_min = None, z_min = None, x_max = None, y_max = None, z_max = None, observer = None) -> int:
  """Pythonic interface to CropVertexGeometry Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    data_container_name (DataArrayPath): Sets the "DataContainerName" filter property
    cropped_data_container_name (DataArrayPath): Sets the "CroppedDataContainerName" filter property
    x_min (float): Sets the "XMin" filter property
    y_min (float): Sets the "YMin" filter property
    z_min (float): Sets the "ZMin" filter property
    x_max (float): Sets the "XMax" filter property
    y_max (float): Sets the "YMax" filter property
    z_max (float): Sets the "ZMax" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = simpl.CropVertexGeometry()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if data_container_name is not None:
    filter.DataContainerName = data_container_name
  if cropped_data_container_name is not None:
    filter.CroppedDataContainerName = cropped_data_container_name
  if x_min is not None:
    filter.XMin = x_min
  if y_min is not None:
    filter.YMin = y_min
  if z_min is not None:
    filter.ZMin = z_min
  if x_max is not None:
    filter.XMax = x_max
  if y_max is not None:
    filter.YMax = y_max
  if z_max is not None:
    filter.ZMax = z_max
  filter.execute()
  return filter.ErrorCode

def data_container_reader(data_container_array, input_file = None, overwrite_existing_data_containers = None, input_file_data_container_array_proxy = None, observer = None) -> int:
  """Pythonic interface to DataContainerReader Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    input_file (QString): Sets the "InputFile" filter property
    overwrite_existing_data_containers (bool): Sets the "OverwriteExistingDataContainers" filter property
    input_file_data_container_array_proxy (DataContainerArrayProxy): Sets the "InputFileDataContainerArrayProxy" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = simpl.DataContainerReader()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if input_file is not None:
    filter.InputFile = input_file
  if overwrite_existing_data_containers is not None:
    filter.OverwriteExistingDataContainers = overwrite_existing_data_containers
  if input_file_data_container_array_proxy is not None:
    filter.InputFileDataContainerArrayProxy = input_file_data_container_array_proxy
  filter.execute()
  return filter.ErrorCode

def data_container_writer(data_container_array, output_file = None, write_xdmf_file = None, write_time_series = None, observer = None) -> int:
  """Pythonic interface to DataContainerWriter Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    output_file (QString): Sets the "OutputFile" filter property
    write_xdmf_file (bool): Sets the "WriteXdmfFile" filter property
    write_time_series (bool): Sets the "WriteTimeSeries" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = simpl.DataContainerWriter()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if output_file is not None:
    filter.OutputFile = output_file
  if write_xdmf_file is not None:
    filter.WriteXdmfFile = write_xdmf_file
  if write_time_series is not None:
    filter.WriteTimeSeries = write_time_series
  filter.execute()
  return filter.ErrorCode

def execute_process(data_container_array, arguments = None, blocking = None, timeout = None, observer = None) -> int:
  """Pythonic interface to ExecuteProcess Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    arguments (QString): Sets the "Arguments" filter property
    blocking (bool): Sets the "Blocking" filter property
    timeout (int): Sets the "Timeout" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = simpl.ExecuteProcess()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if arguments is not None:
    filter.Arguments = arguments
  if blocking is not None:
    filter.Blocking = blocking
  if timeout is not None:
    filter.Timeout = timeout
  filter.execute()
  return filter.ErrorCode

def extract_attribute_arrays_from_geometry(data_container_array, data_container_name = None, shared_vertex_list_array_path0 = None, shared_vertex_list_array_path1 = None, shared_vertex_list_array_path2 = None, shared_vertex_list_array_path3 = None, shared_vertex_list_array_path4 = None, shared_edge_list_array_path = None, shared_tri_list_array_path = None, shared_quad_list_array_path = None, shared_tet_list_array_path = None, x_bounds_array_path = None, y_bounds_array_path = None, z_bounds_array_path = None, observer = None) -> int:
  """Pythonic interface to ExtractAttributeArraysFromGeometry Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    data_container_name (DataArrayPath): Sets the "DataContainerName" filter property
    shared_vertex_list_array_path0 (DataArrayPath): Sets the "SharedVertexListArrayPath0" filter property
    shared_vertex_list_array_path1 (DataArrayPath): Sets the "SharedVertexListArrayPath1" filter property
    shared_vertex_list_array_path2 (DataArrayPath): Sets the "SharedVertexListArrayPath2" filter property
    shared_vertex_list_array_path3 (DataArrayPath): Sets the "SharedVertexListArrayPath3" filter property
    shared_vertex_list_array_path4 (DataArrayPath): Sets the "SharedVertexListArrayPath4" filter property
    shared_edge_list_array_path (DataArrayPath): Sets the "SharedEdgeListArrayPath" filter property
    shared_tri_list_array_path (DataArrayPath): Sets the "SharedTriListArrayPath" filter property
    shared_quad_list_array_path (DataArrayPath): Sets the "SharedQuadListArrayPath" filter property
    shared_tet_list_array_path (DataArrayPath): Sets the "SharedTetListArrayPath" filter property
    x_bounds_array_path (DataArrayPath): Sets the "XBoundsArrayPath" filter property
    y_bounds_array_path (DataArrayPath): Sets the "YBoundsArrayPath" filter property
    z_bounds_array_path (DataArrayPath): Sets the "ZBoundsArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = simpl.ExtractAttributeArraysFromGeometry()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if data_container_name is not None:
    filter.DataContainerName = data_container_name
  if shared_vertex_list_array_path0 is not None:
    filter.SharedVertexListArrayPath0 = shared_vertex_list_array_path0
  if shared_vertex_list_array_path1 is not None:
    filter.SharedVertexListArrayPath1 = shared_vertex_list_array_path1
  if shared_vertex_list_array_path2 is not None:
    filter.SharedVertexListArrayPath2 = shared_vertex_list_array_path2
  if shared_vertex_list_array_path3 is not None:
    filter.SharedVertexListArrayPath3 = shared_vertex_list_array_path3
  if shared_vertex_list_array_path4 is not None:
    filter.SharedVertexListArrayPath4 = shared_vertex_list_array_path4
  if shared_edge_list_array_path is not None:
    filter.SharedEdgeListArrayPath = shared_edge_list_array_path
  if shared_tri_list_array_path is not None:
    filter.SharedTriListArrayPath = shared_tri_list_array_path
  if shared_quad_list_array_path is not None:
    filter.SharedQuadListArrayPath = shared_quad_list_array_path
  if shared_tet_list_array_path is not None:
    filter.SharedTetListArrayPath = shared_tet_list_array_path
  if x_bounds_array_path is not None:
    filter.XBoundsArrayPath = x_bounds_array_path
  if y_bounds_array_path is not None:
    filter.YBoundsArrayPath = y_bounds_array_path
  if z_bounds_array_path is not None:
    filter.ZBoundsArrayPath = z_bounds_array_path
  filter.execute()
  return filter.ErrorCode

def extract_component_as_array(data_container_array, selected_array_path = None, comp_number = None, new_array_array_name = None, observer = None) -> int:
  """Pythonic interface to ExtractComponentAsArray Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    selected_array_path (DataArrayPath): Sets the "SelectedArrayPath" filter property
    comp_number (int): Sets the "CompNumber" filter property
    new_array_array_name (QString): Sets the "NewArrayArrayName" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = simpl.ExtractComponentAsArray()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if selected_array_path is not None:
    filter.SelectedArrayPath = selected_array_path
  if comp_number is not None:
    filter.CompNumber = comp_number
  if new_array_array_name is not None:
    filter.NewArrayArrayName = new_array_array_name
  filter.execute()
  return filter.ErrorCode

def feature_count_decision(data_container_array, feature_ids_array_path = None, max_grains = None, observer = None) -> int:
  """Pythonic interface to FeatureCountDecision Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    feature_ids_array_path (DataArrayPath): Sets the "FeatureIdsArrayPath" filter property
    max_grains (int): Sets the "MaxGrains" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = simpl.FeatureCountDecision()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if feature_ids_array_path is not None:
    filter.FeatureIdsArrayPath = feature_ids_array_path
  if max_grains is not None:
    filter.MaxGrains = max_grains
  filter.execute()
  return filter.ErrorCode

def feature_data_csv_writer(data_container_array, cell_feature_attribute_matrix_path = None, feature_data_file = None, write_neighbor_list_data = None, delimiter_choice = None, write_num_features_line = None, observer = None) -> int:
  """Pythonic interface to FeatureDataCSVWriter Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    cell_feature_attribute_matrix_path (DataArrayPath): Sets the "CellFeatureAttributeMatrixPath" filter property
    feature_data_file (QString): Sets the "FeatureDataFile" filter property
    write_neighbor_list_data (bool): Sets the "WriteNeighborListData" filter property
    delimiter_choice (int): Sets the "DelimiterChoice" filter property
    write_num_features_line (bool): Sets the "WriteNumFeaturesLine" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = simpl.FeatureDataCSVWriter()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if cell_feature_attribute_matrix_path is not None:
    filter.CellFeatureAttributeMatrixPath = cell_feature_attribute_matrix_path
  if feature_data_file is not None:
    filter.FeatureDataFile = feature_data_file
  if write_neighbor_list_data is not None:
    filter.WriteNeighborListData = write_neighbor_list_data
  if delimiter_choice is not None:
    filter.DelimiterChoice = delimiter_choice
  if write_num_features_line is not None:
    filter.WriteNumFeaturesLine = write_num_features_line
  filter.execute()
  return filter.ErrorCode

def find_derivatives(data_container_array, selected_array_path = None, derivatives_array_path = None, observer = None) -> int:
  """Pythonic interface to FindDerivatives Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    selected_array_path (DataArrayPath): Sets the "SelectedArrayPath" filter property
    derivatives_array_path (DataArrayPath): Sets the "DerivativesArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = simpl.FindDerivatives()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if selected_array_path is not None:
    filter.SelectedArrayPath = selected_array_path
  if derivatives_array_path is not None:
    filter.DerivativesArrayPath = derivatives_array_path
  filter.execute()
  return filter.ErrorCode

def generate_color_table(data_container_array, selected_preset_name = None, selected_preset_control_points = None, selected_data_array_path = None, rgb_array_name = None, observer = None) -> int:
  """Pythonic interface to GenerateColorTable Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    selected_preset_name (QString): Sets the "SelectedPresetName" filter property
    selected_preset_control_points (QJsonArray): Sets the "SelectedPresetControlPoints" filter property
    selected_data_array_path (DataArrayPath): Sets the "SelectedDataArrayPath" filter property
    rgb_array_name (QString): Sets the "RgbArrayName" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = simpl.GenerateColorTable()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if selected_preset_name is not None:
    filter.SelectedPresetName = selected_preset_name
  if selected_preset_control_points is not None:
    filter.SelectedPresetControlPoints = selected_preset_control_points
  if selected_data_array_path is not None:
    filter.SelectedDataArrayPath = selected_data_array_path
  if rgb_array_name is not None:
    filter.RgbArrayName = rgb_array_name
  filter.execute()
  return filter.ErrorCode

def generate_tilt_series(data_container_array, rotation_axis = None, rotation_limits = None, spacing = None, input_data_array_path = None, output_prefix = None, observer = None) -> int:
  """Pythonic interface to GenerateTiltSeries Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    rotation_axis (int): Sets the "RotationAxis" filter property
    rotation_limits (float): Sets the "RotationLimits" filter property
    spacing (float): Sets the "Spacing" filter property
    input_data_array_path (DataArrayPath): Sets the "InputDataArrayPath" filter property
    output_prefix (QString): Sets the "OutputPrefix" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = simpl.GenerateTiltSeries()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if rotation_axis is not None:
    filter.RotationAxis = rotation_axis
  if rotation_limits is not None:
    filter.RotationLimits = rotation_limits
  if spacing is not None:
    filter.Spacing = spacing
  if input_data_array_path is not None:
    filter.InputDataArrayPath = input_data_array_path
  if output_prefix is not None:
    filter.OutputPrefix = output_prefix
  filter.execute()
  return filter.ErrorCode

def import_asci_data_array(data_container_array, created_attribute_array_path = None, scalar_type = None, number_of_components = None, skip_header_lines = None, input_file = None, delimiter = None, observer = None) -> int:
  """Pythonic interface to ImportAsciDataArray Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    created_attribute_array_path (DataArrayPath): Sets the "CreatedAttributeArrayPath" filter property
    scalar_type (SIMPL::NumericTypes::Type): Sets the "ScalarType" filter property
    number_of_components (int): Sets the "NumberOfComponents" filter property
    skip_header_lines (int): Sets the "SkipHeaderLines" filter property
    input_file (QString): Sets the "InputFile" filter property
    delimiter (int): Sets the "Delimiter" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = simpl.ImportAsciDataArray()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if created_attribute_array_path is not None:
    filter.CreatedAttributeArrayPath = created_attribute_array_path
  if scalar_type is not None:
    filter.ScalarType = scalar_type
  if number_of_components is not None:
    filter.NumberOfComponents = number_of_components
  if skip_header_lines is not None:
    filter.SkipHeaderLines = skip_header_lines
  if input_file is not None:
    filter.InputFile = input_file
  if delimiter is not None:
    filter.Delimiter = delimiter
  filter.execute()
  return filter.ErrorCode

def import_hdf5_dataset(data_container_array, hdf5_file_path = None, dataset_import_info_list = None, selected_attribute_matrix = None, observer = None) -> int:
  """Pythonic interface to ImportHDF5Dataset Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    hdf5_file_path (QString): Sets the "HDF5FilePath" filter property
    dataset_import_info_list (QList<ImportHDF5Dataset::DatasetImportInfo>): Sets the "DatasetImportInfoList" filter property
    selected_attribute_matrix (DataArrayPath): Sets the "SelectedAttributeMatrix" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = simpl.ImportHDF5Dataset()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if hdf5_file_path is not None:
    filter.HDF5FilePath = hdf5_file_path
  if dataset_import_info_list is not None:
    filter.DatasetImportInfoList = dataset_import_info_list
  if selected_attribute_matrix is not None:
    filter.SelectedAttributeMatrix = selected_attribute_matrix
  filter.execute()
  return filter.ErrorCode

def initialize_data(data_container_array, cell_attribute_matrix_paths = None, x_min = None, y_min = None, z_min = None, x_max = None, y_max = None, z_max = None, init_type = None, random = None, init_value = None, init_range = None, invert_data = None, observer = None) -> int:
  """Pythonic interface to InitializeData Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    cell_attribute_matrix_paths (std::vector<DataArrayPath>): Sets the "CellAttributeMatrixPaths" filter property
    x_min (int): Sets the "XMin" filter property
    y_min (int): Sets the "YMin" filter property
    z_min (int): Sets the "ZMin" filter property
    x_max (int): Sets the "XMax" filter property
    y_max (int): Sets the "YMax" filter property
    z_max (int): Sets the "ZMax" filter property
    init_type (int): Sets the "InitType" filter property
    random (bool): Sets the "Random" filter property
    init_value (double): Sets the "InitValue" filter property
    init_range (FPRangePair): Sets the "InitRange" filter property
    invert_data (bool): Sets the "InvertData" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = simpl.InitializeData()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if cell_attribute_matrix_paths is not None:
    filter.CellAttributeMatrixPaths = cell_attribute_matrix_paths
  if x_min is not None:
    filter.XMin = x_min
  if y_min is not None:
    filter.YMin = y_min
  if z_min is not None:
    filter.ZMin = z_min
  if x_max is not None:
    filter.XMax = x_max
  if y_max is not None:
    filter.YMax = y_max
  if z_max is not None:
    filter.ZMax = z_max
  if init_type is not None:
    filter.InitType = init_type
  if random is not None:
    filter.Random = random
  if init_value is not None:
    filter.InitValue = init_value
  if init_range is not None:
    filter.InitRange = init_range
  if invert_data is not None:
    filter.InvertData = invert_data
  filter.execute()
  return filter.ErrorCode

def link_feature_map_to_element_array(data_container_array, cell_feature_attribute_matrix_name = None, selected_cell_array_path = None, active_array_name = None, observer = None) -> int:
  """Pythonic interface to LinkFeatureMapToElementArray Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    cell_feature_attribute_matrix_name (QString): Sets the "CellFeatureAttributeMatrixName" filter property
    selected_cell_array_path (DataArrayPath): Sets the "SelectedCellArrayPath" filter property
    active_array_name (QString): Sets the "ActiveArrayName" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = simpl.LinkFeatureMapToElementArray()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if cell_feature_attribute_matrix_name is not None:
    filter.CellFeatureAttributeMatrixName = cell_feature_attribute_matrix_name
  if selected_cell_array_path is not None:
    filter.SelectedCellArrayPath = selected_cell_array_path
  if active_array_name is not None:
    filter.ActiveArrayName = active_array_name
  filter.execute()
  return filter.ErrorCode

def mask_count_decision(data_container_array, mask_array_path = None, number_of_trues = None, observer = None) -> int:
  """Pythonic interface to MaskCountDecision Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    mask_array_path (DataArrayPath): Sets the "MaskArrayPath" filter property
    number_of_trues (int): Sets the "NumberOfTrues" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = simpl.MaskCountDecision()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if mask_array_path is not None:
    filter.MaskArrayPath = mask_array_path
  if number_of_trues is not None:
    filter.NumberOfTrues = number_of_trues
  filter.execute()
  return filter.ErrorCode

def move_data(data_container_array, what_to_move = None, data_container_destination = None, attribute_matrix_source = None, attribute_matrix_destination = None, data_array_source = None, observer = None) -> int:
  """Pythonic interface to MoveData Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    what_to_move (int): Sets the "WhatToMove" filter property
    data_container_destination (DataArrayPath): Sets the "DataContainerDestination" filter property
    attribute_matrix_source (DataArrayPath): Sets the "AttributeMatrixSource" filter property
    attribute_matrix_destination (DataArrayPath): Sets the "AttributeMatrixDestination" filter property
    data_array_source (DataArrayPath): Sets the "DataArraySource" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = simpl.MoveData()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if what_to_move is not None:
    filter.WhatToMove = what_to_move
  if data_container_destination is not None:
    filter.DataContainerDestination = data_container_destination
  if attribute_matrix_source is not None:
    filter.AttributeMatrixSource = attribute_matrix_source
  if attribute_matrix_destination is not None:
    filter.AttributeMatrixDestination = attribute_matrix_destination
  if data_array_source is not None:
    filter.DataArraySource = data_array_source
  filter.execute()
  return filter.ErrorCode

def move_multi_data(data_container_array, what_to_move = None, data_container_destination = None, attribute_matrix_sources = None, attribute_matrix_destination = None, data_array_sources = None, observer = None) -> int:
  """Pythonic interface to MoveMultiData Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    what_to_move (int): Sets the "WhatToMove" filter property
    data_container_destination (DataArrayPath): Sets the "DataContainerDestination" filter property
    attribute_matrix_sources (std::vector<DataArrayPath>): Sets the "AttributeMatrixSources" filter property
    attribute_matrix_destination (DataArrayPath): Sets the "AttributeMatrixDestination" filter property
    data_array_sources (std::vector<DataArrayPath>): Sets the "DataArraySources" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = simpl.MoveMultiData()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if what_to_move is not None:
    filter.WhatToMove = what_to_move
  if data_container_destination is not None:
    filter.DataContainerDestination = data_container_destination
  if attribute_matrix_sources is not None:
    filter.AttributeMatrixSources = attribute_matrix_sources
  if attribute_matrix_destination is not None:
    filter.AttributeMatrixDestination = attribute_matrix_destination
  if data_array_sources is not None:
    filter.DataArraySources = data_array_sources
  filter.execute()
  return filter.ErrorCode

def multi_threshold_objects(data_container_array, destination_array_name = None, selected_thresholds = None, scalar_type = None, observer = None) -> int:
  """Pythonic interface to MultiThresholdObjects Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    destination_array_name (QString): Sets the "DestinationArrayName" filter property
    selected_thresholds (ComparisonInputs): Sets the "SelectedThresholds" filter property
    scalar_type (SIMPL::ScalarTypes::Type): Sets the "ScalarType" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = simpl.MultiThresholdObjects()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if destination_array_name is not None:
    filter.DestinationArrayName = destination_array_name
  if selected_thresholds is not None:
    filter.SelectedThresholds = selected_thresholds
  if scalar_type is not None:
    filter.ScalarType = scalar_type
  filter.execute()
  return filter.ErrorCode

def multi_threshold_objects2(data_container_array, destination_array_name = None, selected_thresholds = None, scalar_type = None, observer = None) -> int:
  """Pythonic interface to MultiThresholdObjects2 Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    destination_array_name (QString): Sets the "DestinationArrayName" filter property
    selected_thresholds (ComparisonInputsAdvanced): Sets the "SelectedThresholds" filter property
    scalar_type (SIMPL::ScalarTypes::Type): Sets the "ScalarType" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = simpl.MultiThresholdObjects2()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if destination_array_name is not None:
    filter.DestinationArrayName = destination_array_name
  if selected_thresholds is not None:
    filter.SelectedThresholds = selected_thresholds
  if scalar_type is not None:
    filter.ScalarType = scalar_type
  filter.execute()
  return filter.ErrorCode

def pad_image_geometry(data_container_array, observer = None) -> int:
  """Pythonic interface to PadImageGeometry Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = simpl.PadImageGeometry()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  filter.execute()
  return filter.ErrorCode

def pipeline_annotation(data_container_array, summary = None, observer = None) -> int:
  """Pythonic interface to PipelineAnnotation Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    summary (QString): Sets the "Summary" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = simpl.PipelineAnnotation()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if summary is not None:
    filter.Summary = summary
  filter.execute()
  return filter.ErrorCode

def post_slack_message(data_container_array, slack_user = None, slack_url = None, slack_message = None, warnings_as_error = None, observer = None) -> int:
  """Pythonic interface to PostSlackMessage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    slack_user (QString): Sets the "SlackUser" filter property
    slack_url (QString): Sets the "SlackUrl" filter property
    slack_message (QString): Sets the "SlackMessage" filter property
    warnings_as_error (bool): Sets the "WarningsAsError" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = simpl.PostSlackMessage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if slack_user is not None:
    filter.SlackUser = slack_user
  if slack_url is not None:
    filter.SlackUrl = slack_url
  if slack_message is not None:
    filter.SlackMessage = slack_message
  if warnings_as_error is not None:
    filter.WarningsAsError = warnings_as_error
  filter.execute()
  return filter.ErrorCode

def raw_binary_reader(data_container_array, created_attribute_array_path = None, scalar_type = None, endian = None, number_of_components = None, skip_header_bytes = None, input_file = None, observer = None) -> int:
  """Pythonic interface to RawBinaryReader Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    created_attribute_array_path (DataArrayPath): Sets the "CreatedAttributeArrayPath" filter property
    scalar_type (SIMPL::NumericTypes::Type): Sets the "ScalarType" filter property
    endian (int32_t): Sets the "Endian" filter property
    number_of_components (int32_t): Sets the "NumberOfComponents" filter property
    skip_header_bytes (uint64_t): Sets the "SkipHeaderBytes" filter property
    input_file (QString): Sets the "InputFile" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = simpl.RawBinaryReader()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if created_attribute_array_path is not None:
    filter.CreatedAttributeArrayPath = created_attribute_array_path
  if scalar_type is not None:
    filter.ScalarType = scalar_type
  if endian is not None:
    filter.Endian = endian
  if number_of_components is not None:
    filter.NumberOfComponents = number_of_components
  if skip_header_bytes is not None:
    filter.SkipHeaderBytes = skip_header_bytes
  if input_file is not None:
    filter.InputFile = input_file
  filter.execute()
  return filter.ErrorCode

def read_ascii_data(data_container_array, wizard_data = None, observer = None) -> int:
  """Pythonic interface to ReadASCIIData Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    wizard_data (ASCIIWizardData): Sets the "WizardData" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = simpl.ReadASCIIData()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if wizard_data is not None:
    filter.WizardData = wizard_data
  filter.execute()
  return filter.ErrorCode

def remove_arrays(data_container_array, data_arrays_to_remove = None, observer = None) -> int:
  """Pythonic interface to RemoveArrays Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    data_arrays_to_remove (DataContainerArrayProxy): Sets the "DataArraysToRemove" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = simpl.RemoveArrays()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if data_arrays_to_remove is not None:
    filter.DataArraysToRemove = data_arrays_to_remove
  filter.execute()
  return filter.ErrorCode

def remove_component_from_array(data_container_array, selected_array_path = None, comp_number = None, save_removed_component = None, new_array_array_name = None, reduced_array_array_name = None, observer = None) -> int:
  """Pythonic interface to RemoveComponentFromArray Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    selected_array_path (DataArrayPath): Sets the "SelectedArrayPath" filter property
    comp_number (int): Sets the "CompNumber" filter property
    save_removed_component (bool): Sets the "SaveRemovedComponent" filter property
    new_array_array_name (QString): Sets the "NewArrayArrayName" filter property
    reduced_array_array_name (QString): Sets the "ReducedArrayArrayName" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = simpl.RemoveComponentFromArray()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if selected_array_path is not None:
    filter.SelectedArrayPath = selected_array_path
  if comp_number is not None:
    filter.CompNumber = comp_number
  if save_removed_component is not None:
    filter.SaveRemovedComponent = save_removed_component
  if new_array_array_name is not None:
    filter.NewArrayArrayName = new_array_array_name
  if reduced_array_array_name is not None:
    filter.ReducedArrayArrayName = reduced_array_array_name
  filter.execute()
  return filter.ErrorCode

def rename_attribute_array(data_container_array, selected_array_path = None, new_array_name = None, observer = None) -> int:
  """Pythonic interface to RenameAttributeArray Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    selected_array_path (DataArrayPath): Sets the "SelectedArrayPath" filter property
    new_array_name (QString): Sets the "NewArrayName" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = simpl.RenameAttributeArray()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if selected_array_path is not None:
    filter.SelectedArrayPath = selected_array_path
  if new_array_name is not None:
    filter.NewArrayName = new_array_name
  filter.execute()
  return filter.ErrorCode

def rename_attribute_matrix(data_container_array, selected_attribute_matrix_path = None, new_attribute_matrix = None, observer = None) -> int:
  """Pythonic interface to RenameAttributeMatrix Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    selected_attribute_matrix_path (DataArrayPath): Sets the "SelectedAttributeMatrixPath" filter property
    new_attribute_matrix (QString): Sets the "NewAttributeMatrix" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = simpl.RenameAttributeMatrix()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if selected_attribute_matrix_path is not None:
    filter.SelectedAttributeMatrixPath = selected_attribute_matrix_path
  if new_attribute_matrix is not None:
    filter.NewAttributeMatrix = new_attribute_matrix
  filter.execute()
  return filter.ErrorCode

def rename_data_container(data_container_array, selected_data_container_name = None, new_data_container_name = None, observer = None) -> int:
  """Pythonic interface to RenameDataContainer Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    selected_data_container_name (DataArrayPath): Sets the "SelectedDataContainerName" filter property
    new_data_container_name (DataArrayPath): Sets the "NewDataContainerName" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = simpl.RenameDataContainer()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if selected_data_container_name is not None:
    filter.SelectedDataContainerName = selected_data_container_name
  if new_data_container_name is not None:
    filter.NewDataContainerName = new_data_container_name
  filter.execute()
  return filter.ErrorCode

def replace_value_in_array(data_container_array, selected_array = None, remove_value = None, replace_value = None, observer = None) -> int:
  """Pythonic interface to ReplaceValueInArray Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    selected_array (DataArrayPath): Sets the "SelectedArray" filter property
    remove_value (double): Sets the "RemoveValue" filter property
    replace_value (double): Sets the "ReplaceValue" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = simpl.ReplaceValueInArray()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if selected_array is not None:
    filter.SelectedArray = selected_array
  if remove_value is not None:
    filter.RemoveValue = remove_value
  if replace_value is not None:
    filter.ReplaceValue = replace_value
  filter.execute()
  return filter.ErrorCode

def required_z_thickness(data_container_array, data_container_selection = None, num_z_voxels = None, preflight_check = None, observer = None) -> int:
  """Pythonic interface to RequiredZThickness Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    data_container_selection (DataArrayPath): Sets the "DataContainerSelection" filter property
    num_z_voxels (int): Sets the "NumZVoxels" filter property
    preflight_check (bool): Sets the "PreflightCheck" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = simpl.RequiredZThickness()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if data_container_selection is not None:
    filter.DataContainerSelection = data_container_selection
  if num_z_voxels is not None:
    filter.NumZVoxels = num_z_voxels
  if preflight_check is not None:
    filter.PreflightCheck = preflight_check
  filter.execute()
  return filter.ErrorCode

def rotate_sample_ref_frame(data_container_array, cell_attribute_matrix_path = None, rotation_axis = None, rotation_angle = None, slice_by_slice = None, rotation_table = None, rotation_representation_choice = None, observer = None) -> int:
  """Pythonic interface to RotateSampleRefFrame Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    cell_attribute_matrix_path (DataArrayPath): Sets the "CellAttributeMatrixPath" filter property
    rotation_axis (FloatVec3Type): Sets the "RotationAxis" filter property
    rotation_angle (float): Sets the "RotationAngle" filter property
    slice_by_slice (bool): Sets the "SliceBySlice" filter property
    rotation_table (DynamicTableData): Sets the "RotationTable" filter property
    rotation_representation_choice (int): Sets the "RotationRepresentationChoice" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = simpl.RotateSampleRefFrame()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if cell_attribute_matrix_path is not None:
    filter.CellAttributeMatrixPath = cell_attribute_matrix_path
  if rotation_axis is not None:
    filter.RotationAxis = rotation_axis
  if rotation_angle is not None:
    filter.RotationAngle = rotation_angle
  if slice_by_slice is not None:
    filter.SliceBySlice = slice_by_slice
  if rotation_table is not None:
    filter.RotationTable = rotation_table
  if rotation_representation_choice is not None:
    filter.RotationRepresentationChoice = rotation_representation_choice
  filter.execute()
  return filter.ErrorCode

def scale_volume(data_container_array, data_container_name = None, surface_data_container_name = None, apply_to_voxel_volume = None, apply_to_surface_mesh = None, scale_factor = None, observer = None) -> int:
  """Pythonic interface to ScaleVolume Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    data_container_name (DataArrayPath): Sets the "DataContainerName" filter property
    surface_data_container_name (DataArrayPath): Sets the "SurfaceDataContainerName" filter property
    apply_to_voxel_volume (bool): Sets the "ApplyToVoxelVolume" filter property
    apply_to_surface_mesh (bool): Sets the "ApplyToSurfaceMesh" filter property
    scale_factor (FloatVec3Type): Sets the "ScaleFactor" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = simpl.ScaleVolume()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if data_container_name is not None:
    filter.DataContainerName = data_container_name
  if surface_data_container_name is not None:
    filter.SurfaceDataContainerName = surface_data_container_name
  if apply_to_voxel_volume is not None:
    filter.ApplyToVoxelVolume = apply_to_voxel_volume
  if apply_to_surface_mesh is not None:
    filter.ApplyToSurfaceMesh = apply_to_surface_mesh
  if scale_factor is not None:
    filter.ScaleFactor = scale_factor
  filter.execute()
  return filter.ErrorCode

def set_origin_resolution_image_geom(data_container_array, data_container_name = None, change_origin = None, origin = None, change_resolution = None, spacing = None, observer = None) -> int:
  """Pythonic interface to SetOriginResolutionImageGeom Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    data_container_name (DataArrayPath): Sets the "DataContainerName" filter property
    change_origin (bool): Sets the "ChangeOrigin" filter property
    origin (FloatVec3Type): Sets the "Origin" filter property
    change_resolution (bool): Sets the "ChangeResolution" filter property
    spacing (FloatVec3Type): Sets the "Spacing" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = simpl.SetOriginResolutionImageGeom()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if data_container_name is not None:
    filter.DataContainerName = data_container_name
  if change_origin is not None:
    filter.ChangeOrigin = change_origin
  if origin is not None:
    filter.Origin = origin
  if change_resolution is not None:
    filter.ChangeResolution = change_resolution
  if spacing is not None:
    filter.Spacing = spacing
  filter.execute()
  return filter.ErrorCode

def split_attribute_array(data_container_array, input_array_path = None, split_arrays_suffix = None, observer = None) -> int:
  """Pythonic interface to SplitAttributeArray Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    input_array_path (DataArrayPath): Sets the "InputArrayPath" filter property
    split_arrays_suffix (QString): Sets the "SplitArraysSuffix" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = simpl.SplitAttributeArray()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if input_array_path is not None:
    filter.InputArrayPath = input_array_path
  if split_arrays_suffix is not None:
    filter.SplitArraysSuffix = split_arrays_suffix
  filter.execute()
  return filter.ErrorCode

def write_ascii_data(data_container_array, selected_data_array_paths = None, output_path = None, output_file_path = None, delimiter = None, file_extension = None, max_val_per_line = None, output_style = None, observer = None) -> int:
  """Pythonic interface to WriteASCIIData Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    selected_data_array_paths (std::vector<DataArrayPath>): Sets the "SelectedDataArrayPaths" filter property
    output_path (QString): Sets the "OutputPath" filter property
    output_file_path (QString): Sets the "OutputFilePath" filter property
    delimiter (int): Sets the "Delimiter" filter property
    file_extension (QString): Sets the "FileExtension" filter property
    max_val_per_line (int): Sets the "MaxValPerLine" filter property
    output_style (int): Sets the "OutputStyle" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = simpl.WriteASCIIData()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if selected_data_array_paths is not None:
    filter.SelectedDataArrayPaths = selected_data_array_paths
  if output_path is not None:
    filter.OutputPath = output_path
  if output_file_path is not None:
    filter.OutputFilePath = output_file_path
  if delimiter is not None:
    filter.Delimiter = delimiter
  if file_extension is not None:
    filter.FileExtension = file_extension
  if max_val_per_line is not None:
    filter.MaxValPerLine = max_val_per_line
  if output_style is not None:
    filter.OutputStyle = output_style
  filter.execute()
  return filter.ErrorCode

def write_triangle_geometry(data_container_array, data_container_selection = None, output_nodes_file = None, output_triangles_file = None, observer = None) -> int:
  """Pythonic interface to WriteTriangleGeometry Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    data_container_selection (DataArrayPath): Sets the "DataContainerSelection" filter property
    output_nodes_file (QString): Sets the "OutputNodesFile" filter property
    output_triangles_file (QString): Sets the "OutputTrianglesFile" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = simpl.WriteTriangleGeometry()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if data_container_selection is not None:
    filter.DataContainerSelection = data_container_selection
  if output_nodes_file is not None:
    filter.OutputNodesFile = output_nodes_file
  if output_triangles_file is not None:
    filter.OutputTrianglesFile = output_triangles_file
  filter.execute()
  return filter.ErrorCode

def breakpoint(data_container_array, observer = None) -> int:
  """Pythonic interface to Breakpoint Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = simpl.Breakpoint()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  filter.execute()
  return filter.ErrorCode

def empty_filter(data_container_array, observer = None) -> int:
  """Pythonic interface to EmptyFilter Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = simpl.EmptyFilter()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  filter.execute()
  return filter.ErrorCode

def mass_create_data(data_container_array, data_container_name = None, observer = None) -> int:
  """Pythonic interface to MassCreateData Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    data_container_name (DataArrayPath): Sets the "DataContainerName" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = simpl.MassCreateData()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if data_container_name is not None:
    filter.DataContainerName = data_container_name
  filter.execute()
  return filter.ErrorCode

